:: Automatic Backup, Incremental (ver 3.2)
:: by Dan Vogler, Dan The Computer Man, (210)264-5316
:: https://www.danvoglercomputerman.com

:: Make adjustments at the locations marked with "⚫⚫"
:: Specify variables below (User names, backup drive & folder)
:: To test without copying, use /L at end of SET COPYPARAMS; remove it to actually copy
:: Parameters can be passed to this batch file to specify destination:
::   EXTERNAL (or nothing); INTERNAL; NETWORK
::   Be sure to specify drive letters or network path at those locations.

:: ⚫⚫ (Specify user folder)
SET USR1=Owner
SET USR2=Public
SET USR3=
SET USR4=
:: ⚫⚫ (Specify drive letter)
SET BKUPDRV=D:
SET BKUPFLDR=Backup
SET SSD=C:\Users
SET HDD=C:\Users

:: Use below if only 1 internal drive
::SET HDD=C:\Users
:: Use below if separate SSD/HDD drives, e.g. D:\Data\Owner
::SET HDD=D:\Data
:: or this, e.g. D:\Owner
::SET HDD=D:

SET FILEEXCLUSIONS="Desktop.ini" "Thumbs.db" ".tmp"
SET DIREXCLUSIONS=*Cache* "Service Worker" "File System" "Local Storage" "IndexedDB" "Extension State" "Local Extension Settings" "Pepper Data" "Session Storage" "Storage" "Web Applications"
:: ⚫⚫ (Remove "/L" after testing in order to actually run the backup)
SET COPYPARAMS=/S /XJ /XO /V /R:2 /W:1 /XF %FILEEXCLUSIONS% /XD %DIREXCLUSIONS% /L

IF [%1] == [] (GOTO EXTERNAL) ELSE GOTO %1

:EXTERNAL
CLS
@echo off
@echo Please prepare for a backup.
:: ⚫⚫ (Remove email reminder if no email client)
@echo Close email so it can be backed up.
@echo Make sure the backup drive is plugged in and ready.
PAUSE
echo on
GOTO RUNBACKUP

:INTERNAL
SET BKUPDRV=D:
GOTO RUNBACKUP

:NETWORK
SET BKUPDRV=\\ComputerName

:RUNBACKUP
cls
@echo Your backup is expected to go to Drive %BKUPDRV% in the folder called %BKUPFLDR%.
IF EXIST %BKUPDRV% (GOTO Continue) ELSE (GOTO NotReady)

:NotReady
@echo Your backup drive does not appear to be ready.
PAUSE
GOTO RUNBACKUP

:Continue
@echo Let the backup begin!

:: Special-case folders
For %%F in (
"Special Folder"
"Another Folder"
) do (robocopy "C:\%%~F" "%BKUPDRV%\%BKUPFLDR%\%%~F" %COPYPARAMS%)
:: ⚫⚫ (See drive letter above)
:: ⚫⚫ (Remove PAUSE command after testing)
PAUSE

FOR %%U IN ("%USR1%" "%USR2%" "%USR3%" "%USR4%") DO (

FOR %%F IN (Desktop Documents Downloads Music Pictures Videos) DO (
robocopy "%HDD%\%%~U\%%~F" "%BKUPDRV%\%BKUPFLDR%\%%~U\%%~F" %COPYPARAMS%)
:: ⚫⚫ (Remove PAUSE command after testing)
PAUSE
FOR %%F IN (Contacts Favorites Dropbox OneDrive) DO (
robocopy "%SSD%\%%~U\%%~F" "%BKUPDRV%\%BKUPFLDR%\%%~U\%%~F" %COPYPARAMS%)

:: Located under AppData\Local
For %%F in (
"Google\Chrome\User Data\Default"
"Microsoft\Outlook"
"Microsoft\Windows Mail"
"Microsoft\Windows Live Mail"
"Microsoft\Windows Live Contacts"
"Microsoft\Windows Live\Contacts"
) do (robocopy "%SSD%\%%~U\AppData\Local\%%~F" "%BKUPDRV%\%BKUPFLDR%\%%~U\%%~F" %COPYPARAMS%)

:: Located under AppData\Roaming
For %%F in (
"Mozilla\Firefox\Profiles"
"Microsoft\Outlook"
"Thunderbird\Profiles"
) do (robocopy "%SSD%\%%~U\AppData\Roaming\%%~F" "%BKUPDRV%\%BKUPFLDR%\%%~U\%%~F" %COPYPARAMS%)

:: Outlook duplicate (From Dest to Dest)
For %%F in (
"Outlook"
"Microsoft\Outlook"
"Documents\Outlook Files"
) do (robocopy "%BKUPDRV%\%BKUPFLDR%\%%~U\%%~F" "%BKUPDRV%\%BKUPFLDR%\%%~U\Outlook Duplicate" %COPYPARAMS%)

)
:: Above parenthesis closes loop for Users

date/t>>"%BKUPDRV%\%BKUPFLDR%\LastBackup.txt"
time/t>>"%BKUPDRV%\%BKUPFLDR%\LastBackup.txt"


::Syntax note: ~ expands variable but removes surrounding quotes.